class District():
    def __init__(self, name, regionId, regionName, isActive, id):
        self.name = name
        self.regionId = regionId
        self.regionName = regionName
        self.isActive = isActive
        self.id = id
