class Municipality():
    def __init__(self, name, districtId, districtName, regionId, regionName, isActive, id):
        self.name = name
        self.districtId = districtId
        self.districtName = districtName
        self.regionId = regionId
        self.regionName = regionName
        self.isActive = isActive
        self.id = id
