class Address():
    def __init__(self, municipalityId, municipalityName, districtId, districtName, regionId, regionName, houseNumber, referenceNumber, zip, streetName, streetId, text, isActive, id):
        self.municipalityId = municipalityId
        self.municipalityName = municipalityName
        self.districtId = districtId
        self.districtName = districtName
        self.regionId = regionId
        self.regionName = regionName
        self.houseNumber = houseNumber
        self.referenceNumber = referenceNumber
        self.zip = zip
        self.streetName = streetName
        self.streetId = streetId
        self.text = text
        self.isActive = isActive
        self.id = id
