class Organization():
    def __init__(self, id, abraCustomerId, address, hasActiveContract, icoNumber, isActual, isCustomer, name, abraCode, xUcastnikId, clientId, updatedAt, updatedBy, isMember, isCanceledMemberPart, masterOrganizationId, masterOrganizationAbraId, masterOrganizationName,  entityId, isVip, vipNote, organizationTypeId, organizationTypeName):
        self.id = id
        self.abraCustomerId = abraCustomerId
        self.addres = address
        self.hasActiveContract = hasActiveContract
        self.icoNumber = icoNumber
        self.isActual = isActual
        self.isCustomer = isCustomer
        self.name = name
        self.abraCode = abraCode
        self.xUcastnikId = xUcastnikId
        self.clientId = clientId
        self.updatedAt = updatedAt
        self.updatedBy = updatedBy
        self.isMember = isMember
        self.isCanceledMemberPart = isCanceledMemberPart
        self.masterOrganizationId = masterOrganizationId
        self.masterOrganizationAbraId = masterOrganizationAbraId
        self.masterOrganizationName = masterOrganizationName
        self.entityId = entityId
        self.isVip = isVip
        self.vipNote = vipNote
        self.organizationTypeId = organizationTypeId
        self.organizationTypeName = organizationTypeName
